summaryrefslogtreecommitdiff
path: root/src/utils/gettexthelper.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/utils/gettexthelper.cpp')
-rw-r--r--src/utils/gettexthelper.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/utils/gettexthelper.cpp b/src/utils/gettexthelper.cpp
index 66ebcb469..1bbe328cd 100644
--- a/src/utils/gettexthelper.cpp
+++ b/src/utils/gettexthelper.cpp
@@ -1,8 +1,8 @@
/*
* The ManaPlus Client
* Copyright (C) 2011-2019 The ManaPlus Developers
*
* This file is part of The ManaPlus Client.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -107,7 +107,7 @@ void GettextHelper::initLang()
#else // ENABLE_PORTABLE
#ifdef __APPLE__
bindTextDomain((std::string(VirtFs::getBaseDir())
- .append("ManaPlus.app/Contents/Resources/locale/")).c_str());
+ .append("ManaVerse.app/Contents/Resources/locale/")).c_str());
#else // __APPLE__
bindTextDomain(LOCALEDIR);
@@ -129,8 +129,8 @@ void GettextHelper::initLang()
else
logger->log("locale empty");
}
- bind_textdomain_codeset("manaplus", "UTF-8");
- textdomain("manaplus");
+ bind_textdomain_codeset("manaverse", "UTF-8");
+ textdomain("manaverse");
#elif defined(ENABLE_CUSTOMNLS)
mainTranslator = new PoDict("en");
setLangEnv();
@@ -140,7 +140,7 @@ void GettextHelper::initLang()
#ifdef ENABLE_NLS
void GettextHelper::bindTextDomain(const char *const path)
{
- const char *const dir = bindtextdomain("manaplus", path);
+ const char *const dir = bindtextdomain("manaverse", path);
if (dir)
logger->log("bindtextdomain: %s", dir);
else
@@ -1,8 +1,8 @@
/*
- * The ManaPlus Client
+ * The ManaVerse Client
* Copyright (C) 2011-2019 The ManaPlus Developers
*
@@ -1,8 +1,8 @@
* Copyright (C) 2011-2019 The ManaPlus Developers
*
- * This file is part of The ManaPlus Client.
+ * This file is part of The ManaVerse Client.
*
* This program is free software; you can redistribute it and/or modify